@@ -938,7 +938,12 @@ def handle_interrupt(func=None, cbs=(), verbose=True):
     which we can access because the instance will be the first element of
     `args` (passed in as `self`).
 
-    Note: Kwargs are passed to callbacks as a single dict, not as **kwargs.
+    Notes:
+    -Kwargs are passed to callbacks as a single dict, not as **kwargs.
+    -A 'status_code' parameter tracks whether the last call was successful.
+    The decorated function obviously can't reference the status of the current
+    call since it's unknown until the function call completes, but the
+    status is updated before executing any callbacks.
 
     Parameters
     ----------
@@ -949,15 +954,23 @@ def handle_interrupt(func=None, cbs=(), verbose=True):
     verbose: bool
         If True, print a message to stdout when an interrupt occurs.
     """
-    if not func: return partial(handle_interrupt, cbs=cbs, verbose=verbose)
+    if not func:
+        return partial(handle_interrupt, cbs=tolist(cbs), verbose=verbose)
+    func.status_code = 0
+    for cb in cbs:
+        cb.setup(func)
     @wraps(func)
     def wrapper(*args, **kwargs):
         func_inputs = bound_args(func, args, kwargs, collapse_kwargs=False)
+        for cb in cbs:
+            cb.on_begin(func, func_inputs)
         try:
             res = func(*args, **kwargs)
+            wrapper.status_code = 0
         except KeyboardInterrupt:
             if verbose: print('KeyboardInterrupt. Aborting...')
             res = None
+            wrapper.status_code = 1
         finally:
             for cb in cbs:
                 cb.on_end(func, func_inputs, res)
@@ -1893,7 +1906,7 @@ def handle(func=None, default=None):
 
 
 @contextmanager
-def block_timer():
+def block_timer(name=''):
     """Context manager to time a block of code. This works similarly to @timer
     but can be used on code outside of functions.
 
@@ -1905,13 +1918,19 @@ def block_timer():
         first = None
         while first != '100':
             arr.pop(0)
+    print(bt['duration'])
+
+    1.25   # Float measuring time spent in context manager.
     """
+    data = {}
+    if name: name = repr(name) + ' '
     start = time.perf_counter()
     try:
-        yield
+        yield data
     finally:
         duration = time.perf_counter() - start
-        print(f'[TIMER]: Block executed in {duration:.3f} seconds.')
+        print(f'[TIMER]: Block {name}executed in {duration:.3f} seconds.')
+        data['duration'] = duration
 
 
 def count_calls(func):
