@@ -820,7 +820,7 @@ class FuzzyKeyDict(_FuzzyDictBase):
         pairs = process.extract(key,
                                 self.keys(),
                                 limit=n_keys or self.n_keys,
-                                scorer=scorer or fuzz.ratio)
+                                scorer=scorer or self.scorer)
         return self._filter_similarity_pairs(pairs, mode=mode)
 
 
@@ -1046,6 +1046,10 @@ class Results:
     """
 
     def __init__(self, **kwargs):
+        for x in ('items', 'keys', 'values', '_keys', '_asdict', 'from_dict'):
+            if x in kwargs:
+                raise ValueError(f'{x!r} is a reserved attribute name.')
+
         self._keys = list(kwargs)
         self.__dict__.update(kwargs)
 
